@@ -10,7 +10,6 @@
 import pyutilib.misc
 from pyutilib.component.core import *
 from pyutilib.component.config import ExecutableOption, declare_option
-#dir(pyutilib.component.config)
 
 class IExternalExecutable(Interface):
     """Interface for plugins that define an external executable"""
@@ -37,6 +36,10 @@ class ExternalExecutable(Plugin):
             self.path=kwds['path']
         else:
             self.path=None
+        if 'validate' in kwds:
+            self.validate=kwds['validate']
+        else:
+            self.validate=None
         self.find_executable()
 
     def find_executable(self):
@@ -45,7 +48,7 @@ class ExternalExecutable(Plugin):
         else:
             self.exec_default = pyutilib.misc.search_file(self.name,
                                 implicitExt=pyutilib.misc.executable_extension,
-                                executable=True)
+                                executable=True, validate=self.validate)
 
     def enabled(self):
         return self._enable and ((self.executable is not None) or (self.exec_default is not None))
